"""Console script for tuttusa_utils."""

import fire

def help():
    print("tuttusa_utils")
    print("=" * len("tuttusa_utils"))
    print("Utils for Tuttusa")

def main():
    fire.Fire({
        "help": help
    })


if __name__ == "__main__":
    main() # pragma: no cover



#!/usr/bin/env python
"""Tests for `tuttusa_utils` package."""
# pylint: disable=redefined-outer-name

import pytest
import numpy as np
from tuttusa_utils.tuttusa_utils import store_syth, load_synth, upload_data_to_cloud, download_data_from_cloud


@pytest.fixture
def fake_data():
    return np.random.uniform(0, 1, (20, 30))


def test_store_load_locally(fake_data):
    """can store and load synthetic data locally"""

    store_syth(fake_data, "fake_data_test")

    n_fake_data = load_synth("fake_data_test")

    assert (n_fake_data == fake_data).all()


@pytest.mark.skip(reason="no way of currently testing this")
def test_store_load_cloud(fake_data):
    """can store and load synthetic data to the cloud"""
    upload_data_to_cloud(fake_data, "fake_data_test")

    n_fake_data = download_data_from_cloud("fake_data_test")

    assert (n_fake_data == fake_data).all()



import pathlib
import pickle
import tempfile
from pathlib import Path
from zipfile import ZipFile, ZIP_DEFLATED

import requests
from pip._internal.utils.appdirs import user_cache_dir
from tqdm import tqdm

bucket_name = "tuttusa-raw"

main_data_path = pathlib.Path(user_cache_dir("tuttusa_raw"))
main_data_path.mkdir(parents=True, exist_ok=True)

import os
import boto3


def aws_session(region_name='us-east-1'):
    aws_key_id = os.environ.get('AWS_ACCESS_KEY_ID')
    aws_key_secret = os.environ.get('AWS_ACCESS_KEY_SECRET')

    assert aws_key_id is not None, "AWS_ACCESS_KEY_ID must be set in environement path"
    assert aws_key_secret is not None, "AWS_ACCESS_KEY_SECRET must be set in environement path"

    return boto3.session.Session(aws_access_key_id=os.getenv('AWS_ACCESS_KEY_ID'),
                                 aws_secret_access_key=os.getenv('AWS_ACCESS_KEY_SECRET'),
                                 region_name=region_name)


def store_syth(data, name):
    path = main_data_path.joinpath(name).as_posix()
    with open(path, 'wb') as file:
        pickle.dump(data, file)
        file.close()


def load_synth(name):
    path = main_data_path.joinpath(name).as_posix()
    if isinstance(path, str):
        with open(path, 'rb') as file:
            return pickle.load(file)
    else:
        return pickle.load(path)


def make_zip(tree_path, zip_path, mode='w', skip_empty_dir=False):
    with ZipFile(zip_path, mode=mode, compression=ZIP_DEFLATED) as zf:
        paths = [Path(tree_path)]
        while paths:
            p = paths.pop()
            if p.is_dir():
                paths.extend(p.iterdir())
                if skip_empty_dir:
                    continue
            zf.write(p, p.relative_to(tree_path))


def download_file(url, name):
    chunk_size = 1024
    r = requests.get(url, stream=True)
    pbar = tqdm(unit="B", total=int(r.headers['Content-Length']))
    path = main_data_path.joinpath(name).as_posix()
    with open(path, 'wb') as file:
        for chunk in r.iter_content(chunk_size=chunk_size):
            if chunk:  # filter out keep-alive new chunks
                pbar.update(len(chunk))
                file.write(chunk)
        file.close()


def upload_data_to_cloud(data, name):
    session = aws_session()
    s3_resource = session.resource('s3')

    new_file, filename = tempfile.mkstemp()

    with open(filename, 'wb') as file:
        pickle.dump(data, file)
        file.close()

    bucket = s3_resource.Bucket(bucket_name)
    bucket.upload_file(Filename=filename, Key=name)


def download_data_from_cloud(name):
    u = f"https://{bucket_name}.s3.amazonaws.com/{name}"
    path = main_data_path.joinpath(name).as_posix()
    download_file(u, path)
    return load_synth(name)



from setuptools import setup, find_packages
from os.path import abspath, dirname, join

README_MD = open(join(dirname(abspath(__file__)), "README.md")).read()

setup(
    name='tuttusa_utils',         # How you named your package folder (MyLib)
    #packages=['tuttusa_utils'],   # Chose the same as "name"
    version='0.1',      # Start with a small number and increase it with every change you make
    packages=find_packages(exclude="tests"),
    # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    license='MIT',
    description='Tuttusa Utils',   # Give a short description about your library
    long_description=README_MD,
    long_description_content_type="text/markdown",
    author='Ashish',                   # Type in your name
    author_email='agarwal.ashish.singhal@gmail.com',      # Type in your E-Mail
    # Provide either the link to your github or to your website
    url='https://github.com/Tuttusa/tuttusa-utils',
    # I explain this later on
    download_url='https://github.com/Tuttusa/tuttusa-utils/archive/v_01.tar.gz',
    keywords=['utils', 'pypi', 'Tuttusa'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
        'fire',
		'tqdm',
		'google-cloud-storage',
		'sklearn',
		'boto3',
		'dload',
		'requests'
    ],
    include_package_data=True,
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        #'Programming Language :: Python :: 3.4',
        #'Programming Language :: Python :: 3.5',
        #'Programming Language :: Python :: 3.6',
        #'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
